InsufficientShares class final

Fewer than ThresholdParams.t shares were supplied.

Inheritance

Constructors

InsufficientShares(String message)
Creates an insufficient-shares error.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
Describes the failure; safe to log (must not contain secret material).
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited