SerializationError class final

Binary parse failure or unknown format version/kind/scheme.

Inheritance

Constructors

SerializationError(String message)
Creates a serialization error.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
Describes the failure; safe to log (must not contain secret material).
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited