Transcript class final
Hash-chain transcript of public ceremony data only.
Constructors
-
Transcript.create({required Uint8List ceremonyId, required ThresholdParams params, required List<
String> participantIds}) -
Creates an empty transcript for a ceremony.
factory
- Transcript.fromBytes(Uint8List bytes)
-
Parses a sealed transcript.
factory
Properties
- ceremonyId → Uint8List
-
Ceremony identifier.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- params → ThresholdParams
-
Threshold parameters.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
appendRound(
{required int round, required int senderIndex, required Uint8List messageBytes}) → void - Records a public round message hash.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
seal(
{PublicKey? finalPublicKey, required bool success, String? abortReason}) → Uint8List - Seals the transcript with ceremony outcome.
-
toBytes(
) → Uint8List - Canonical serialized bytes.
-
toString(
) → String -
A string representation of this object.
inherited
-
verify(
) → bool - Verifies hash chain integrity.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited