VerifiableSecretSharing class abstract final

Dealer-based verifiable secret sharing (C2).

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

reconstruct({required List<Share> shares}) → Uint8List
Reconstructs the secret from at least params.t shares.
split({required ThresholdParams params, required Uint8List ceremonyId, required Uint8List secret, Iterable<String>? participantIds}) → ({PublicKey publicKey, List<Share> shares, List<Uint8List> verificationData})
Dealer splits secret into params.n verifiable shares.
verifyShare({required Share share, required List<Uint8List> verificationData}) → void
Recipient verifies share against Feldman verificationData.