Orchestration for ML-DSA threshold root generation (C1 beta).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
simulate(
ThresholdParams params, {Uint8List? ceremonyId, List< String> ? participantIds, String? mithrilBridgePath}) → Future<({MlDsaPublicKey publicKey, List< MlDsaShare> shares})> - In-process C1 simulation via Mithril RSS keygen (Tier 2).