MlDsaThresholdProfile enum

Maps pqthreshold ML-DSA SchemeId values to pqforge algorithms.

Inheritance
Available extensions

Values

mlDsa44 → const MlDsaThresholdProfile

ML-DSA-44 (NIST category 2).

const MlDsaThresholdProfile(SchemeId.mlDsa44ThresholdV1, PqSignatureAlgorithm.mlDsa44)
mlDsa65 → const MlDsaThresholdProfile

ML-DSA-65 (NIST category 3) — primary v2 target.

const MlDsaThresholdProfile(SchemeId.mlDsa65ThresholdV1, PqSignatureAlgorithm.mlDsa65)
mlDsa87 → const MlDsaThresholdProfile

ML-DSA-87 (NIST category 5).

const MlDsaThresholdProfile(SchemeId.mlDsa87ThresholdV1, PqSignatureAlgorithm.mlDsa87)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
pqforgeAlgorithm → PqSignatureAlgorithm
pqforge verification algorithm.
final
publicKeyLength → int
Expected FIPS 204 public key length.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemeId → SchemeId
Corresponding SchemeId.
final
signatureLength → int
Expected FIPS 204 signature length.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromScheme(SchemeId scheme) → MlDsaThresholdProfile
Resolves scheme to a profile.
matchesScheme(SchemeId scheme) → bool
Whether scheme is one of the ML-DSA threshold profiles (not hybrid).

Constants

values → const List<MlDsaThresholdProfile>
A constant List of the values in this enum, in order of their declaration.