MlDsaThresholdSigner class abstract final

Threshold ML-DSA signing (C3) — M2 beta via Mithril bridge.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

sign({required List<MlDsaShare> shares, required Uint8List message, Uint8List? context, String? mithrilBridgePath}) → Future<Uint8List>
Threshold-sign message with ≥ params.t shares from shares.
signWithWire({required List<MlDsaShare> shares, required Uint8List message, Uint8List? context, String? mithrilBridgePath}) → Future<({Uint8List sessionId, Uint8List signature, List<MlDsaSigningMessage> wireMessages})>
Threshold-sign and export Mithril wire round payloads (M3 beta).