MlDsaThresholdSigningCeremony class abstract final

Orchestration for ML-DSA threshold signing (C3 beta).

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

simulate({required List<MlDsaShare> shares, required Uint8List message, Uint8List? context, String? mithrilBridgePath}) → Future<Uint8List>
In-process C3 via Mithril bridge — Tier 2 tests and examples.