MlDsaThresholdVerifier class abstract final

Verifies threshold-produced ML-DSA signatures (FIPS 204 output shape).

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

verify({required SchemeId scheme, required Uint8List publicKey, required Uint8List message, required Uint8List signature, Uint8List? context, bool preHash = false}) → bool
Verifies signature under publicKey using pqforge.