MlDsaWireSubKind class abstract final

Protocol message sub-kind bytes for ML-DSA threshold signing.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

round1Commit → const int
round2Reveal → const int
round3Response → const int