SchemeMilestone enum

Production and API readiness for a SchemeId.

Inheritance
Available extensions

Values

production → const SchemeMilestone

Shipped in v1.

alpha → const SchemeMilestone

Registry + verify path only (M1).

beta → const SchemeMilestone

DKG + sign in development (M2).

planned → const SchemeMilestone

Not yet specified.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<SchemeMilestone>
A constant List of the values in this enum, in order of their declaration.