RotationSimulator class abstract final

Runs C5 rotation in one process — tests, examples, and docs only.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

run({required List<Share> oldShares, required PublicKey oldPublicKey, Uint8List? newCeremonyId, int? signedAtUnixSeconds}) → Future<({ContinuityProof continuityProof, PublicKey newPublicKey, List<Share> newShares, Transcript newTranscript})>
Delegates to RotationCeremony.simulate.