MlDsaThresholdSimulator class abstract final

Runs ML-DSA threshold C1+C3 in one process (M2 beta — requires Mithril).

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

run({required ThresholdParams params, required Uint8List message, Uint8List? ceremonyId, List<String>? participantIds, String? mithrilBridgePath}) → Future<Uint8List>
Full C1 → C3 simulation for ML-DSA-44.