Dealer-based verifiable secret sharing (C2).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
reconstruct(
{}) → Uint8List -
Reconstructs the secret from at least
params.tshares. -
split(
{required ThresholdParams params, required Uint8List ceremonyId, required Uint8List secret, Iterable< String> ? participantIds}) → ({PublicKey publicKey, List<Share> shares, List<Uint8List> verificationData}) -
Dealer splits
secretintoparams.nverifiable shares. -
Recipient verifies
shareagainst FeldmanverificationData.