MlDsaSigningMessage class final
Typed wrapper for ML-DSA threshold signing protocol envelopes.
Constructors
- MlDsaSigningMessage.fromBytes(Uint8List bytes)
-
factory
- MlDsaSigningMessage.round1({required ThresholdParams params, required Uint8List ceremonyId, required int senderIndex, required Uint8List sessionId, required Uint8List commitmentHash})
-
factory
- MlDsaSigningMessage.round2({required ThresholdParams params, required Uint8List ceremonyId, required int senderIndex, required Uint8List sessionId, required Uint8List revealBytes})
-
factory
- MlDsaSigningMessage.round3({required ThresholdParams params, required Uint8List ceremonyId, required int senderIndex, required Uint8List sessionId, required Uint8List responseBytes})
-
factory
Properties
- ceremonyId → Uint8List
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → int
-
final
- payload → Uint8List
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheme → SchemeId
-
final
- senderIndex → int
-
final
- sessionId → Uint8List
-
final
- subKind → int
-
final
- wireBytes → Uint8List
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transcriptHash(
) → Uint8List
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited