MlDsaSigningSession class final
Officer-local ML-DSA signing state between distributed wire rounds.
Checkpoints contain the ceremony seed — never publish or relay.
Constructors
- MlDsaSigningSession.fromCheckpoint(Uint8List bytes)
-
factory
Properties
-
activePartyIdsZeroBased
→ List<
int> -
final
- ceremonyId → Uint8List
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → Uint8List
-
final
- params → ThresholdParams
-
final
- publicKeyFingerprint → Uint8List
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → Uint8List
-
final
- signerIndex → int
-
final
Methods
-
completeRound2(
{required Iterable< MlDsaSigningMessage> round1Messages}) → Future<MlDsaSigningMessage> - Completes Round2 after collecting Round1 wire messages for all activePartyIdsZeroBased.
-
completeRound3(
{required Iterable< MlDsaSigningMessage> round1Messages, required Iterable<MlDsaSigningMessage> round2Messages}) → Future<MlDsaSigningMessage> - Completes Round3 after collecting Round1 + Round2 wire messages.
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCheckpoint(
) → Uint8List -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
begin(
{required Uint8List message, required MlDsaPublicKey publicKey, required List< int> activePartyIdsZeroBased, String? mithrilBridgePath}) → Future<({MlDsaSigningMessage round1, MlDsaSigningSession session})> -
Starts Round1 for
shareagainstpublicKeyandactivePartyIdsZeroBased. -
paramsSchemeMismatch(
MlDsaPublicKey publicKey) → bool