Runs a full DKG ceremony in one process.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
run(
{required ThresholdParams params, Uint8List? ceremonyId, List< String> ? participantIds}) → ({PublicKey publicKey, List<Share> shares, List<Transcript> transcripts}) -
Simulates C1 for all
params.nparticipants.